DKLogLevel enum

日志级别

Inheritance
Available extensions

Values

debug → const DKLogLevel

调试信息

const DKLogLevel(0, '🐛 DEBUG', '\x1B[36m')
info → const DKLogLevel

普通信息

const DKLogLevel(1, 'ℹ️ INFO', '\x1B[37m')
warning → const DKLogLevel

警告信息

const DKLogLevel(2, '⚠️ WARN', '\x1B[33m')
error → const DKLogLevel

错误信息

const DKLogLevel(3, '❌ ERROR', '\x1B[31m')
fatal → const DKLogLevel

严重错误

const DKLogLevel(4, '💀 FATAL', '\x1B[35m')
success → const DKLogLevel

成功信息

const DKLogLevel(5, '✅ SUCCESS', '\x1B[32m')
temp → const DKLogLevel

临时调试(橙色,用于开发时的临时log,方便识别和清理)

const DKLogLevel(6, '🔶 TEMP', '\x1B[38;5;208m')

Properties

color String
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
label String
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DKLogLevel>
A constant List of the values in this enum, in order of their declaration.