LogLevel enum
日志级别枚举
Values
- all → const LogLevel
-
const LogLevel('全部', null) - debug → const LogLevel
-
const LogLevel('DEBUG', '🐛') - info → const LogLevel
-
const LogLevel('INFO', 'ℹ️') - warning → const LogLevel
-
const LogLevel('WARN', '⚠️') - error → const LogLevel
-
const LogLevel('ERROR', '❌') - fatal → const LogLevel
-
const LogLevel('FATAL', '💀')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → String?
-
final
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited