FileLogExample class

文件日志操作示例

Constructors

FileLogExample()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clearLogs() Future<void>
清空所有日志
exportLogs() Future<String?>
导出日志
init() Future<void>
初始化文件日志
listLogFiles() Future<void>
获取所有日志文件
readLatestLog() Future<String?>
读取日志文件内容