WebSocketLogExample class

WebSocket 日志示例

用于将日志实时传输到电脑端查看

Constructors

WebSocketLogExample()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

checkStatus() → void
检查连接状态
disable() Future<void>
禁用 WebSocket 日志
enableAutoDiscover() Future<void>
启用 WebSocket 日志(自动发现服务器)
enableManual() Future<void>
启用 WebSocket 日志(手动指定服务器)
reconnect() Future<void>
手动重连
setConnectionCallback() → void
设置连接状态回调