DKStateEventSuccess<T> class

状态:成功

Inheritance

Constructors

DKStateEventSuccess(String runId, T data, {String? message})
const

Properties

data → T
final
errorMessage String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isError bool
no setterinherited
isIdle bool
no setterinherited
isLoading bool
no setterinherited
isSuccess bool
no setterinherited
message String?
final
runId String
运行 ID,用于日志追踪
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited