User class

DKState 使用示例

本文件包含 DKStateQuery 和 DKStateEvent 两种状态管理方式的完整使用示例 示例数据模型

Constructors

User({required int id, required String name, required String email})

Properties

email String
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited