DKStateQuery<T> class
sealed
DkStateQuery - 用于 GET 查询操作的状态管理 适用场景:
- GET 请求(列表、详情)
- 页面数据加载
- 需要保持状态的场景
- 配合 状态管理 使用 特点:
- 状态持久化(配置重建后恢复)
- 全量 UI 渲染
- 适合 Display() 组件展示
Properties
- data → T
-
no setter
- errorMessage → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
no setter
- isError → bool
-
no setter
- isIdle → bool
-
no setter
- isLoading → bool
-
no setter
- isSuccess → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited