DkStateQueryExtensions class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
empty<
T> () → DKStateQuery< T> -
error<
T> (String message) → DKStateQuery< T> -
idle<
T> () → DKStateQuery< T> -
loading<
T> () → DKStateQuery< T> -
success<
T> (T data) → DKStateQuery< T>