DkStateQuerySuccess<T> class
成功状态
- Inheritance
-
- Object
- DKStateQuery<
T> - DkStateQuerySuccess
Constructors
- DkStateQuerySuccess(T data)
-
const
Properties
- data → T
-
final
- errorMessage → String
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
no setterinherited
- isError → bool
-
no setterinherited
- isIdle → bool
-
no setterinherited
- isLoading → bool
-
no setterinherited
- isSuccess → bool
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited