AppRoutes class
应用路由配置
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
routes
→ Map<
String, WidgetBuilder> -
路由表
no setter
Constants
- home → const String
- logExample → const String
- logView → const String
- stateCombinedExample → const String
- stateEventExample → const String
- stateQueryExample → const String