LogWebSocketClient class
WebSocket 日志客户端 通过 mDNS 服务发现连接到电脑端的日志服务器
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConnected → bool
-
是否已连接
no setter
- isEnabled → bool
-
是否已启用
no setter
- onConnectionStatusChanged ↔ void Function(bool connected)?
-
连接状态回调
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
disable(
) → Future< void> - 禁用 WebSocket 日志传输
-
enable(
{bool autoDiscover = true, String? host, int? port, String? path, String? serviceName}) → Future< void> - 启用 WebSocket 日志传输
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reconnect(
) → Future< void> - 手动重连(用于用户界面)
-
sendLog(
Map< String, dynamic> logData) → void - 发送日志消息
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → LogWebSocketClient
-
no setter